You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@activemq.apache.org by cl...@apache.org on 2018/10/10 22:49:01 UTC

[2/3] activemq-artemis git commit: ARTEMIS-1018 de-duplicate logging codes

ARTEMIS-1018 de-duplicate logging codes


Project: http://git-wip-us.apache.org/repos/asf/activemq-artemis/repo
Commit: http://git-wip-us.apache.org/repos/asf/activemq-artemis/commit/b3529dce
Tree: http://git-wip-us.apache.org/repos/asf/activemq-artemis/tree/b3529dce
Diff: http://git-wip-us.apache.org/repos/asf/activemq-artemis/diff/b3529dce

Branch: refs/heads/master
Commit: b3529dcea428fa697aacbceacc6641e47cfb74ba
Parents: 76595e7
Author: Justin Bertram <jb...@apache.org>
Authored: Tue Oct 2 15:31:23 2018 -0500
Committer: Clebert Suconic <cl...@apache.org>
Committed: Wed Oct 10 18:48:53 2018 -0400

----------------------------------------------------------------------
 .../core/client/ActiveMQClientLogger.java       |   4 +-
 .../client/ActiveMQClientMessageBundle.java     | 126 +++++-----
 .../jms/client/ActiveMQJMSClientBundle.java     |  38 +--
 .../jms/client/ActiveMQJMSClientLogger.java     |  22 +-
 .../jms/bridge/ActiveMQJMSBridgeLogger.java     |   2 +-
 .../jms/server/ActiveMQJMSServerBundle.java     |   2 +-
 .../activemq/artemis/jlibaio/NativeLogger.java  |   8 +-
 .../ActiveMQAMQPProtocolMessageBundle.java      |  36 +--
 .../artemis/core/protocol/mqtt/MQTTLogger.java  |   2 +-
 .../stomp/ActiveMQStompProtocolLogger.java      |  12 +-
 .../ActiveMQStompProtocolMessageBundle.java     |   2 +-
 .../artemis/osgi/ActiveMQOsgiLogger.java        |   2 +-
 .../core/server/ActiveMQMessageBundle.java      | 240 +++++++++----------
 .../core/server/ActiveMQServerLogger.java       |  30 +--
 .../ActiveMQServiceExtensionLogger.java         |   8 +-
 .../xa/recovery/ActiveMQXARecoveryLogger.java   |  36 +--
 .../activemq/artemis/ActiveMQWebLogger.java     |   2 +-
 17 files changed, 286 insertions(+), 286 deletions(-)
----------------------------------------------------------------------


http://git-wip-us.apache.org/repos/asf/activemq-artemis/blob/b3529dce/artemis-core-client/src/main/java/org/apache/activemq/artemis/core/client/ActiveMQClientLogger.java
----------------------------------------------------------------------
diff --git a/artemis-core-client/src/main/java/org/apache/activemq/artemis/core/client/ActiveMQClientLogger.java b/artemis-core-client/src/main/java/org/apache/activemq/artemis/core/client/ActiveMQClientLogger.java
index 8d087a3..e8fdc08 100644
--- a/artemis-core-client/src/main/java/org/apache/activemq/artemis/core/client/ActiveMQClientLogger.java
+++ b/artemis-core-client/src/main/java/org/apache/activemq/artemis/core/client/ActiveMQClientLogger.java
@@ -32,7 +32,7 @@ import java.net.UnknownHostException;
 /**
  * Logger Code 21
  * <p>
- * Each message id must be 6 digits long starting with 10, the 3rd digit donates the level so
+ * Each message id must be 6 digits long starting with 21, the 3rd digit donates the level so
  *
  * <pre>
  * INF0  1
@@ -43,7 +43,7 @@ import java.net.UnknownHostException;
  * FATAL 6
  * </pre>
  *
- * so an INFO message would be 101000 to 101999.
+ * so an INFO message would be 211000 to 211999.
  * <p>
  * Once released, methods should not be deleted as they may be referenced by knowledge base
  * articles. Unused methods should be marked as deprecated.

http://git-wip-us.apache.org/repos/asf/activemq-artemis/blob/b3529dce/artemis-core-client/src/main/java/org/apache/activemq/artemis/core/client/ActiveMQClientMessageBundle.java
----------------------------------------------------------------------
diff --git a/artemis-core-client/src/main/java/org/apache/activemq/artemis/core/client/ActiveMQClientMessageBundle.java b/artemis-core-client/src/main/java/org/apache/activemq/artemis/core/client/ActiveMQClientMessageBundle.java
index e043ac9..66b8184 100644
--- a/artemis-core-client/src/main/java/org/apache/activemq/artemis/core/client/ActiveMQClientMessageBundle.java
+++ b/artemis-core-client/src/main/java/org/apache/activemq/artemis/core/client/ActiveMQClientMessageBundle.java
@@ -39,196 +39,196 @@ import org.jboss.logging.annotations.MessageBundle;
 import org.w3c.dom.Node;
 
 /**
- * Logger Code 11
+ * Logger Code 21
  *
- * each message id must be 6 digits long starting with 10, the 3rd digit should be 9
+ * each message id must be 6 digits long starting with 21, the 3rd digit should be 9
  *
- * so 119000 to 119999
+ * so 219000 to 219999
  */
 @MessageBundle(projectCode = "AMQ")
 public interface ActiveMQClientMessageBundle {
 
    ActiveMQClientMessageBundle BUNDLE = Messages.getBundle(ActiveMQClientMessageBundle.class);
 
-   @Message(id = 119000, value = "ClientSession closed while creating session")
+   @Message(id = 219000, value = "ClientSession closed while creating session")
    ActiveMQInternalErrorException clientSessionClosed();
 
-   @Message(id = 119001, value = "Failed to create session")
+   @Message(id = 219001, value = "Failed to create session")
    ActiveMQInternalErrorException failedToCreateSession(@Cause Throwable t);
 
-   @Message(id = 119003, value = "Queue can not be both durable and temporary")
+   @Message(id = 219003, value = "Queue can not be both durable and temporary")
    ActiveMQInternalErrorException queueMisConfigured();
 
-   @Message(id = 119004, value = "Failed to initialise session factory")
+   @Message(id = 219004, value = "Failed to initialise session factory")
    ActiveMQInternalErrorException failedToInitialiseSessionFactory(@Cause Exception e);
 
-   @Message(id = 119005, value = "Exception in Netty transport")
+   @Message(id = 219005, value = "Exception in Netty transport")
    ActiveMQInternalErrorException nettyError();
 
-   @Message(id = 119006, value = "Channel disconnected")
+   @Message(id = 219006, value = "Channel disconnected")
    ActiveMQNotConnectedException channelDisconnected();
 
-   @Message(id = 119007, value = "Cannot connect to server(s). Tried with all available servers.")
+   @Message(id = 219007, value = "Cannot connect to server(s). Tried with all available servers.")
    ActiveMQNotConnectedException cannotConnectToServers();
 
-   @Message(id = 119008, value = "Failed to connect to any static connectors")
+   @Message(id = 219008, value = "Failed to connect to any static connectors")
    ActiveMQNotConnectedException cannotConnectToStaticConnectors(@Cause Exception e);
 
-   @Message(id = 119009, value = "Failed to connect to any static connectors")
+   @Message(id = 219009, value = "Failed to connect to any static connectors")
    ActiveMQNotConnectedException cannotConnectToStaticConnectors2();
 
-   @Message(id = 119010, value = "Connection is destroyed")
+   @Message(id = 219010, value = "Connection is destroyed")
    ActiveMQNotConnectedException connectionDestroyed();
 
-   @Message(id = 119011, value = "Did not receive data from server for {0}", format = Message.Format.MESSAGE_FORMAT)
+   @Message(id = 219011, value = "Did not receive data from server for {0}", format = Message.Format.MESSAGE_FORMAT)
    ActiveMQConnectionTimedOutException connectionTimedOut(Connection transportConnection);
 
-   @Message(id = 119012, value = "Timed out waiting to receive initial broadcast from cluster")
+   @Message(id = 219012, value = "Timed out waiting to receive initial broadcast from cluster")
    ActiveMQConnectionTimedOutException connectionTimedOutInInitialBroadcast();
 
-   @Message(id = 119013, value = "Timed out waiting to receive cluster topology. Group:{0}", format = Message.Format.MESSAGE_FORMAT)
+   @Message(id = 219013, value = "Timed out waiting to receive cluster topology. Group:{0}", format = Message.Format.MESSAGE_FORMAT)
    ActiveMQConnectionTimedOutException connectionTimedOutOnReceiveTopology(DiscoveryGroup discoveryGroup);
 
-   @Message(id = 119014, value = "Timed out after waiting {0} ms for response when sending packet {1}", format = Message.Format.MESSAGE_FORMAT)
+   @Message(id = 219014, value = "Timed out after waiting {0} ms for response when sending packet {1}", format = Message.Format.MESSAGE_FORMAT)
    ActiveMQConnectionTimedOutException timedOutSendingPacket(long timeout, Byte type);
 
-   @Message(id = 119015, value = "The connection was disconnected because of server shutdown")
+   @Message(id = 219015, value = "The connection was disconnected because of server shutdown")
    ActiveMQDisconnectedException disconnected();
 
-   @Message(id = 119016, value = "Connection failure detected. Unblocking a blocking call that will never get a response")
+   @Message(id = 219016, value = "Connection failure detected. Unblocking a blocking call that will never get a response")
    ActiveMQUnBlockedException unblockingACall(@Cause Throwable t);
 
-   @Message(id = 119017, value = "Consumer is closed")
+   @Message(id = 219017, value = "Consumer is closed")
    ActiveMQObjectClosedException consumerClosed();
 
-   @Message(id = 119018, value = "Producer is closed")
+   @Message(id = 219018, value = "Producer is closed")
    ActiveMQObjectClosedException producerClosed();
 
-   @Message(id = 119019, value = "Session is closed")
+   @Message(id = 219019, value = "Session is closed")
    ActiveMQObjectClosedException sessionClosed();
 
-   @Message(id = 119020, value = "Cannot call receive(...) - a MessageHandler is set")
+   @Message(id = 219020, value = "Cannot call receive(...) - a MessageHandler is set")
    ActiveMQIllegalStateException messageHandlerSet();
 
-   @Message(id = 119021, value = "Cannot set MessageHandler - consumer is in receive(...)")
+   @Message(id = 219021, value = "Cannot set MessageHandler - consumer is in receive(...)")
    ActiveMQIllegalStateException inReceive();
 
-   @Message(id = 119022, value = "Header size ({0}) is too big, use the messageBody for large data, or increase minLargeMessageSize",
+   @Message(id = 219022, value = "Header size ({0}) is too big, use the messageBody for large data, or increase minLargeMessageSize",
       format = Message.Format.MESSAGE_FORMAT)
    ActiveMQIllegalStateException headerSizeTooBig(Integer headerSize);
 
-   @Message(id = 119023, value = "The large message lost connection with its session, either because of a rollback or a closed session")
+   @Message(id = 219023, value = "The large message lost connection with its session, either because of a rollback or a closed session")
    ActiveMQIllegalStateException largeMessageLostSession();
 
-   @Message(id = 119024, value = "Could not select a TransportConfiguration to create SessionFactory")
+   @Message(id = 219024, value = "Could not select a TransportConfiguration to create SessionFactory")
    ActiveMQIllegalStateException noTCForSessionFactory();
 
-   @Message(id = 119025, value = "Error saving the message body")
+   @Message(id = 219025, value = "Error saving the message body")
    ActiveMQLargeMessageException errorSavingBody(@Cause Exception e);
 
-   @Message(id = 119026, value = "Error reading the LargeMessageBody")
+   @Message(id = 219026, value = "Error reading the LargeMessageBody")
    ActiveMQLargeMessageException errorReadingBody(@Cause Exception e);
 
-   @Message(id = 119027, value = "Error closing stream from LargeMessageBody")
+   @Message(id = 219027, value = "Error closing stream from LargeMessageBody")
    ActiveMQLargeMessageException errorClosingLargeMessage(@Cause Exception e);
 
-   @Message(id = 119028, value = "Timeout waiting for LargeMessage Body")
+   @Message(id = 219028, value = "Timeout waiting for LargeMessage Body")
    ActiveMQLargeMessageException timeoutOnLargeMessage();
 
-   @Message(id = 119029, value = "Error writing body of message")
+   @Message(id = 219029, value = "Error writing body of message")
    ActiveMQLargeMessageException errorWritingLargeMessage(@Cause Exception e);
 
-   @Message(id = 119030, value = "The transaction was rolled back on failover to a backup server")
+   @Message(id = 219030, value = "The transaction was rolled back on failover to a backup server")
    ActiveMQTransactionRolledBackException txRolledBack();
 
-   @Message(id = 119031, value = "The transaction was rolled back on failover however commit may have been successful")
+   @Message(id = 219031, value = "The transaction was rolled back on failover however commit may have been successful")
    ActiveMQTransactionOutcomeUnknownException txOutcomeUnknown();
 
-   @Message(id = 119032, value = "Invalid type: {0}", format = Message.Format.MESSAGE_FORMAT)
+   @Message(id = 219032, value = "Invalid type: {0}", format = Message.Format.MESSAGE_FORMAT)
    IllegalArgumentException invalidType(Object type);
 
-   @Message(id = 119033, value = "Invalid type: {0}", format = Message.Format.MESSAGE_FORMAT)
+   @Message(id = 219033, value = "Invalid type: {0}", format = Message.Format.MESSAGE_FORMAT)
    IllegalArgumentException invalidEncodeType(Object type);
 
-   @Message(id = 119034, value = "Params for management operations must be of the following type: int long double String boolean Map or array thereof but found {0}",
+   @Message(id = 219034, value = "Params for management operations must be of the following type: int long double String boolean Map or array thereof but found {0}",
       format = Message.Format.MESSAGE_FORMAT)
    IllegalArgumentException invalidManagementParam(Object type);
 
-   @Message(id = 119035, value = "Invalid window size {0}", format = Message.Format.MESSAGE_FORMAT)
+   @Message(id = 219035, value = "Invalid window size {0}", format = Message.Format.MESSAGE_FORMAT)
    IllegalArgumentException invalidWindowSize(Integer size);
 
-   @Message(id = 119037, value = "Invalid last Received Command ID: {0}", format = Message.Format.MESSAGE_FORMAT)
+   @Message(id = 219037, value = "Invalid last Received Command ID: {0}", format = Message.Format.MESSAGE_FORMAT)
    IllegalArgumentException invalidCommandID(Integer lastReceivedCommandID);
 
-   @Message(id = 119038, value = "Cannot find channel with id {0} to close", format = Message.Format.MESSAGE_FORMAT)
+   @Message(id = 219038, value = "Cannot find channel with id {0} to close", format = Message.Format.MESSAGE_FORMAT)
    IllegalArgumentException noChannelToClose(Long id);
 
-   @Message(id = 119039, value = "Close Listener cannot be null")
+   @Message(id = 219039, value = "Close Listener cannot be null")
    IllegalArgumentException closeListenerCannotBeNull();
 
-   @Message(id = 119040, value = "Fail Listener cannot be null")
+   @Message(id = 219040, value = "Fail Listener cannot be null")
    IllegalArgumentException failListenerCannotBeNull();
 
-   @Message(id = 119041, value = "Connection already exists with id {0}", format = Message.Format.MESSAGE_FORMAT)
+   @Message(id = 219041, value = "Connection already exists with id {0}", format = Message.Format.MESSAGE_FORMAT)
    IllegalArgumentException connectionExists(Object id);
 
-   @Message(id = 119042, value = "Invalid argument null listener")
+   @Message(id = 219042, value = "Invalid argument null listener")
    IllegalArgumentException nullListener();
 
-   @Message(id = 119043, value = "Invalid argument null handler")
+   @Message(id = 219043, value = "Invalid argument null handler")
    IllegalArgumentException nullHandler();
 
-   @Message(id = 119045, value = "the first node to be compared is null")
+   @Message(id = 219045, value = "the first node to be compared is null")
    IllegalArgumentException firstNodeNull();
 
-   @Message(id = 119046, value = "the second node to be compared is null")
+   @Message(id = 219046, value = "the second node to be compared is null")
    IllegalArgumentException secondNodeNull();
 
-   @Message(id = 119047, value = "nodes have different node names")
+   @Message(id = 219047, value = "nodes have different node names")
    IllegalArgumentException nodeHaveDifferentNames();
 
-   @Message(id = 119048, value = "nodes have a different number of attributes")
+   @Message(id = 219048, value = "nodes have a different number of attributes")
    IllegalArgumentException nodeHaveDifferentAttNumber();
 
-   @Message(id = 119049, value = "attribute {0}={1} does not match", format = Message.Format.MESSAGE_FORMAT)
+   @Message(id = 219049, value = "attribute {0}={1} does not match", format = Message.Format.MESSAGE_FORMAT)
    IllegalArgumentException attsDontMatch(String name, String value);
 
-   @Message(id = 119050, value = "one node has children and the other does not")
+   @Message(id = 219050, value = "one node has children and the other does not")
    IllegalArgumentException oneNodeHasChildren();
 
-   @Message(id = 119051, value = "nodes have a different number of children")
+   @Message(id = 219051, value = "nodes have a different number of children")
    IllegalArgumentException nodeHasDifferentChildNumber();
 
-   @Message(id = 119052, value = "Element {0} requires a valid Boolean value, but ''{1}'' cannot be parsed as a Boolean", format = Message.Format.MESSAGE_FORMAT)
+   @Message(id = 219052, value = "Element {0} requires a valid Boolean value, but ''{1}'' cannot be parsed as a Boolean", format = Message.Format.MESSAGE_FORMAT)
    IllegalArgumentException mustBeBoolean(Node elem, String value);
 
-   @Message(id = 119053, value = "Element {0} requires a valid Double value, but ''{1}'' cannot be parsed as a Double", format = Message.Format.MESSAGE_FORMAT)
+   @Message(id = 219053, value = "Element {0} requires a valid Double value, but ''{1}'' cannot be parsed as a Double", format = Message.Format.MESSAGE_FORMAT)
    IllegalArgumentException mustBeDouble(Node elem, String value);
 
-   @Message(id = 119054, value = "Element {0} requires a valid Integer value, but ''{1}'' cannot be parsed as an Integer", format = Message.Format.MESSAGE_FORMAT)
+   @Message(id = 219054, value = "Element {0} requires a valid Integer value, but ''{1}'' cannot be parsed as an Integer", format = Message.Format.MESSAGE_FORMAT)
    IllegalArgumentException mustBeInteger(Node elem, String value);
 
-   @Message(id = 119055, value = "Element {0} requires a valid Long value, but ''{1}'' cannot be parsed as a Long", format = Message.Format.MESSAGE_FORMAT)
+   @Message(id = 219055, value = "Element {0} requires a valid Long value, but ''{1}'' cannot be parsed as a Long", format = Message.Format.MESSAGE_FORMAT)
    IllegalArgumentException mustBeLong(Node element, String value);
 
-   @Message(id = 119057, value = "Error decoding password")
+   @Message(id = 219057, value = "Error decoding password")
    IllegalArgumentException errordecodingPassword(@Cause Exception e);
 
-   @Message(id = 119058, value = "Address \"{0}\" is full. Message encode size = {1}B", format = Message.Format.MESSAGE_FORMAT)
+   @Message(id = 219058, value = "Address \"{0}\" is full. Message encode size = {1}B", format = Message.Format.MESSAGE_FORMAT)
    ActiveMQAddressFullException addressIsFull(String addressName, int size);
 
-   @Message(id = 119059, value = "Interceptor {0} rejected packet in a blocking call. This call will never complete.", format = Message.Format.MESSAGE_FORMAT)
+   @Message(id = 219059, value = "Interceptor {0} rejected packet in a blocking call. This call will never complete.", format = Message.Format.MESSAGE_FORMAT)
    ActiveMQInterceptorRejectedPacketException interceptorRejectedPacket(String interceptionResult);
 
-   @Message(id = 119060, value = "Large Message Transmission interrupted on consumer shutdown.")
+   @Message(id = 219060, value = "Large Message Transmission interrupted on consumer shutdown.")
    ActiveMQLargeMessageInterruptedException largeMessageInterrupted();
 
-   @Message(id = 119061, value = "Cannot send a packet while channel is failing over.")
+   @Message(id = 219061, value = "Cannot send a packet while channel is failing over.")
    IllegalStateException cannotSendPacketDuringFailover();
 
-   @Message(id = 119062, value = "Multi-packet transmission (e.g. Large Messages) interrupted because of a reconnection.")
+   @Message(id = 219062, value = "Multi-packet transmission (e.g. Large Messages) interrupted because of a reconnection.")
    ActiveMQInterruptedException packetTransmissionInterrupted();
 
-   @Message(id = 119063, value = "Cannot send a packet while response cache is full.")
+   @Message(id = 219063, value = "Cannot send a packet while response cache is full.")
    IllegalStateException cannotSendPacketWhilstResponseCacheFull();
 }

http://git-wip-us.apache.org/repos/asf/activemq-artemis/blob/b3529dce/artemis-jms-client/src/main/java/org/apache/activemq/artemis/jms/client/ActiveMQJMSClientBundle.java
----------------------------------------------------------------------
diff --git a/artemis-jms-client/src/main/java/org/apache/activemq/artemis/jms/client/ActiveMQJMSClientBundle.java b/artemis-jms-client/src/main/java/org/apache/activemq/artemis/jms/client/ActiveMQJMSClientBundle.java
index 844446c..9472af8 100644
--- a/artemis-jms-client/src/main/java/org/apache/activemq/artemis/jms/client/ActiveMQJMSClientBundle.java
+++ b/artemis-jms-client/src/main/java/org/apache/activemq/artemis/jms/client/ActiveMQJMSClientBundle.java
@@ -34,63 +34,63 @@ import org.jboss.logging.annotations.Message;
 import org.jboss.logging.annotations.MessageBundle;
 
 /**
- * Logger Code 12
+ * Logger Code 13
  *
- * each message id must be 6 digits long starting with 10, the 3rd digit should be 9
+ * each message id must be 6 digits long starting with 13, the 3rd digit should be 9
  *
- * so 129000 to 129999
+ * so 139000 to 139999
  */
 @MessageBundle(projectCode = "AMQ")
 public interface ActiveMQJMSClientBundle {
 
    ActiveMQJMSClientBundle BUNDLE = Messages.getBundle(ActiveMQJMSClientBundle.class);
 
-   @Message(id = 129000, value = "Invalid filter: {0}", format = Message.Format.MESSAGE_FORMAT)
+   @Message(id = 139000, value = "Invalid filter: {0}", format = Message.Format.MESSAGE_FORMAT)
    ActiveMQInvalidFilterExpressionException invalidFilter(@Cause Throwable e, SimpleString filter);
 
-   @Message(id = 129001, value = "Invalid Subscription Name. It is required to set the subscription name")
+   @Message(id = 139001, value = "Invalid Subscription Name. It is required to set the subscription name")
    ActiveMQIllegalStateException invalidSubscriptionName();
 
-   @Message(id = 129002, value = "Destination {0} does not exist", format = Message.Format.MESSAGE_FORMAT)
+   @Message(id = 139002, value = "Destination {0} does not exist", format = Message.Format.MESSAGE_FORMAT)
    ActiveMQNonExistentQueueException destinationDoesNotExist(SimpleString destination);
 
-   @Message(id = 129003, value = "name cannot be null")
+   @Message(id = 139003, value = "name cannot be null")
    IllegalArgumentException nameCannotBeNull();
 
-   @Message(id = 129004, value = "name cannot be empty")
+   @Message(id = 139004, value = "name cannot be empty")
    IllegalArgumentException nameCannotBeEmpty();
 
-   @Message(id = 129005, value = "It is illegal to call this method from within a Message Listener")
+   @Message(id = 139005, value = "It is illegal to call this method from within a Message Listener")
    IllegalStateRuntimeException callingMethodFromListenerRuntime();
 
-   @Message(id = 129006, value = "It is illegal to call this method from within a Message Listener")
+   @Message(id = 139006, value = "It is illegal to call this method from within a Message Listener")
    IllegalStateException callingMethodFromListener();
 
-   @Message(id = 129007, value = "It is illegal to call this method from within a Completion Listener")
+   @Message(id = 139007, value = "It is illegal to call this method from within a Completion Listener")
    IllegalStateRuntimeException callingMethodFromCompletionListenerRuntime();
 
-   @Message(id = 129008, value = "It is illegal to call this method from within a Completion Listener")
+   @Message(id = 139008, value = "It is illegal to call this method from within a Completion Listener")
    IllegalStateException callingMethodFromCompletionListener();
 
-   @Message(id = 129009, value = "Null {0} is not allowed", format = Message.Format.MESSAGE_FORMAT)
+   @Message(id = 139009, value = "Null {0} is not allowed", format = Message.Format.MESSAGE_FORMAT)
    IllegalArgumentException nullArgumentNotAllowed(String type);
 
-   @Message(id = 129010, value = "Topic (Destination) cannot be null")
+   @Message(id = 139010, value = "Topic (Destination) cannot be null")
    InvalidDestinationException nullTopic();
 
-   @Message(id = 129011, value = "LargeMessage streaming is only possible on ByteMessage or StreamMessage")
+   @Message(id = 139011, value = "LargeMessage streaming is only possible on ByteMessage or StreamMessage")
    IllegalStateException onlyValidForByteOrStreamMessages();
 
-   @Message(id = 129012, value = "The property name ''{0}'' is not a valid java identifier.",
+   @Message(id = 139012, value = "The property name ''{0}'' is not a valid java identifier.",
       format = Message.Format.MESSAGE_FORMAT)
    JMSRuntimeException invalidJavaIdentifier(String propertyName);
 
-   @Message(id = 129013, value = "Message is read-only")
+   @Message(id = 139013, value = "Message is read-only")
    MessageNotWriteableException messageNotWritable();
 
-   @Message(id = 129014, value = "Message is write-only")
+   @Message(id = 139014, value = "Message is write-only")
    MessageNotReadableException messageNotReadable();
 
-   @Message(id = 129015, value = "Illegal deliveryMode value: {0}", format = Message.Format.MESSAGE_FORMAT)
+   @Message(id = 139015, value = "Illegal deliveryMode value: {0}", format = Message.Format.MESSAGE_FORMAT)
    JMSException illegalDeliveryMode(int deliveryMode);
 }

http://git-wip-us.apache.org/repos/asf/activemq-artemis/blob/b3529dce/artemis-jms-client/src/main/java/org/apache/activemq/artemis/jms/client/ActiveMQJMSClientLogger.java
----------------------------------------------------------------------
diff --git a/artemis-jms-client/src/main/java/org/apache/activemq/artemis/jms/client/ActiveMQJMSClientLogger.java b/artemis-jms-client/src/main/java/org/apache/activemq/artemis/jms/client/ActiveMQJMSClientLogger.java
index 3f11696..4b65085 100644
--- a/artemis-jms-client/src/main/java/org/apache/activemq/artemis/jms/client/ActiveMQJMSClientLogger.java
+++ b/artemis-jms-client/src/main/java/org/apache/activemq/artemis/jms/client/ActiveMQJMSClientLogger.java
@@ -24,9 +24,9 @@ import org.jboss.logging.annotations.Message;
 import org.jboss.logging.annotations.MessageLogger;
 
 /**
- * Logger Code 12
+ * Logger Code 13
  *
- * each message id must be 6 digits long starting with 12, the 3rd digit donates the level so
+ * each message id must be 6 digits long starting with 13, the 3rd digit donates the level so
  *
  * INF0  1
  * WARN  2
@@ -35,7 +35,7 @@ import org.jboss.logging.annotations.MessageLogger;
  * TRACE 5
  * FATAL 6
  *
- * so an INFO message would be 121000 to 121999
+ * so an INFO message would be 131000 to 131999
  */
 @MessageLogger(projectCode = "AMQ")
 public interface ActiveMQJMSClientLogger extends BasicLogger {
@@ -46,35 +46,35 @@ public interface ActiveMQJMSClientLogger extends BasicLogger {
    ActiveMQJMSClientLogger LOGGER = Logger.getMessageLogger(ActiveMQJMSClientLogger.class, ActiveMQJMSClientLogger.class.getPackage().getName());
 
    @LogMessage(level = Logger.Level.WARN)
-   @Message(id = 122000, value = "I''m closing a JMS connection you left open. Please make sure you close all JMS connections explicitly before letting them go out of scope! see stacktrace to find out where it was created", format = Message.Format.MESSAGE_FORMAT)
+   @Message(id = 132000, value = "I''m closing a JMS connection you left open. Please make sure you close all JMS connections explicitly before letting them go out of scope! see stacktrace to find out where it was created", format = Message.Format.MESSAGE_FORMAT)
    void connectionLeftOpen(@Cause Exception e);
 
    @LogMessage(level = Logger.Level.WARN)
-   @Message(id = 122001, value = "Unhandled exception thrown from onMessage", format = Message.Format.MESSAGE_FORMAT)
+   @Message(id = 132001, value = "Unhandled exception thrown from onMessage", format = Message.Format.MESSAGE_FORMAT)
    void onMessageError(@Cause Exception e);
 
    @LogMessage(level = Logger.Level.ERROR)
-   @Message(id = 124000, value = "Failed to call JMS exception listener", format = Message.Format.MESSAGE_FORMAT)
+   @Message(id = 134000, value = "Failed to call JMS exception listener", format = Message.Format.MESSAGE_FORMAT)
    void errorCallingExcListener(@Cause Exception e);
 
    @LogMessage(level = Logger.Level.ERROR)
-   @Message(id = 124002, value = "Queue Browser failed to create message {0}", format = Message.Format.MESSAGE_FORMAT)
+   @Message(id = 134002, value = "Queue Browser failed to create message {0}", format = Message.Format.MESSAGE_FORMAT)
    void errorCreatingMessage(String messageToString, @Cause Throwable e);
 
    @LogMessage(level = Logger.Level.ERROR)
-   @Message(id = 124003, value = "Message Listener failed to prepare message for receipt, message={0}", format = Message.Format.MESSAGE_FORMAT)
+   @Message(id = 134003, value = "Message Listener failed to prepare message for receipt, message={0}", format = Message.Format.MESSAGE_FORMAT)
    void errorPreparingMessageForReceipt(String messagetoString, @Cause Throwable e);
 
    @LogMessage(level = Logger.Level.ERROR)
-   @Message(id = 124004, value = "Message Listener failed to process message", format = Message.Format.MESSAGE_FORMAT)
+   @Message(id = 134004, value = "Message Listener failed to process message", format = Message.Format.MESSAGE_FORMAT)
    void errorProcessingMessage(@Cause Throwable e);
 
    @LogMessage(level = Logger.Level.ERROR)
-   @Message(id = 124005, value = "Message Listener failed to recover session", format = Message.Format.MESSAGE_FORMAT)
+   @Message(id = 134005, value = "Message Listener failed to recover session", format = Message.Format.MESSAGE_FORMAT)
    void errorRecoveringSession(@Cause Throwable e);
 
    @LogMessage(level = Logger.Level.ERROR)
-   @Message(id = 124006, value = "Failed to call Failover listener", format = Message.Format.MESSAGE_FORMAT)
+   @Message(id = 134006, value = "Failed to call Failover listener", format = Message.Format.MESSAGE_FORMAT)
    void errorCallingFailoverListener(@Cause Exception e);
 
 }

http://git-wip-us.apache.org/repos/asf/activemq-artemis/blob/b3529dce/artemis-jms-server/src/main/java/org/apache/activemq/artemis/jms/bridge/ActiveMQJMSBridgeLogger.java
----------------------------------------------------------------------
diff --git a/artemis-jms-server/src/main/java/org/apache/activemq/artemis/jms/bridge/ActiveMQJMSBridgeLogger.java b/artemis-jms-server/src/main/java/org/apache/activemq/artemis/jms/bridge/ActiveMQJMSBridgeLogger.java
index d75a4e6..59553ac 100644
--- a/artemis-jms-server/src/main/java/org/apache/activemq/artemis/jms/bridge/ActiveMQJMSBridgeLogger.java
+++ b/artemis-jms-server/src/main/java/org/apache/activemq/artemis/jms/bridge/ActiveMQJMSBridgeLogger.java
@@ -28,7 +28,7 @@ import org.jboss.logging.annotations.MessageLogger;
 /**
  * Logger Code 34
  *
- * each message id must be 6 digits long starting with 12, the 3rd digit donates the level so
+ * each message id must be 6 digits long starting with 34, the 3rd digit donates the level so
  *
  * INF0  1
  * WARN  2

http://git-wip-us.apache.org/repos/asf/activemq-artemis/blob/b3529dce/artemis-jms-server/src/main/java/org/apache/activemq/artemis/jms/server/ActiveMQJMSServerBundle.java
----------------------------------------------------------------------
diff --git a/artemis-jms-server/src/main/java/org/apache/activemq/artemis/jms/server/ActiveMQJMSServerBundle.java b/artemis-jms-server/src/main/java/org/apache/activemq/artemis/jms/server/ActiveMQJMSServerBundle.java
index c442832..e0c9d3c 100644
--- a/artemis-jms-server/src/main/java/org/apache/activemq/artemis/jms/server/ActiveMQJMSServerBundle.java
+++ b/artemis-jms-server/src/main/java/org/apache/activemq/artemis/jms/server/ActiveMQJMSServerBundle.java
@@ -27,7 +27,7 @@ import org.jboss.logging.annotations.MessageBundle;
 /**
  * Logger Code 12
  *
- * each message id must be 6 digits long starting with 10, the 3rd digit should be 9
+ * each message id must be 6 digits long starting with 12, the 3rd digit should be 9
  *
  * so 129000 to 129999
  */

http://git-wip-us.apache.org/repos/asf/activemq-artemis/blob/b3529dce/artemis-native/src/main/java/org/apache/activemq/artemis/jlibaio/NativeLogger.java
----------------------------------------------------------------------
diff --git a/artemis-native/src/main/java/org/apache/activemq/artemis/jlibaio/NativeLogger.java b/artemis-native/src/main/java/org/apache/activemq/artemis/jlibaio/NativeLogger.java
index 0bd95db..8a40851 100644
--- a/artemis-native/src/main/java/org/apache/activemq/artemis/jlibaio/NativeLogger.java
+++ b/artemis-native/src/main/java/org/apache/activemq/artemis/jlibaio/NativeLogger.java
@@ -23,9 +23,9 @@ import org.jboss.logging.annotations.Message;
 import org.jboss.logging.annotations.MessageLogger;
 
 /**
- * Logger Code 14
+ * Logger Code 16
  *
- * each message id must be 6 digits long starting with 14, the 3rd digit denotes the level so
+ * each message id must be 6 digits long starting with 16, the 3rd digit denotes the level so
  *
  * INF0  1
  * WARN  2
@@ -34,7 +34,7 @@ import org.jboss.logging.annotations.MessageLogger;
  * TRACE 5
  * FATAL 6
  *
- * so an INFO message would be 141000 to 141999
+ * so an INFO message would be 161000 to 161999
  */
 @MessageLogger(projectCode = "jlibaio")
 public interface NativeLogger extends BasicLogger {
@@ -45,6 +45,6 @@ public interface NativeLogger extends BasicLogger {
    NativeLogger LOGGER = Logger.getMessageLogger(NativeLogger.class, NativeLogger.class.getPackage().getName());
 
    @LogMessage(level = Logger.Level.WARN)
-   @Message(id = 143001, value = "You have a native library with a different version than expected", format = Message.Format.MESSAGE_FORMAT)
+   @Message(id = 163001, value = "You have a native library with a different version than expected", format = Message.Format.MESSAGE_FORMAT)
    void incompatibleNativeLibrary();
 }

http://git-wip-us.apache.org/repos/asf/activemq-artemis/blob/b3529dce/artemis-protocols/artemis-amqp-protocol/src/main/java/org/apache/activemq/artemis/protocol/amqp/logger/ActiveMQAMQPProtocolMessageBundle.java
----------------------------------------------------------------------
diff --git a/artemis-protocols/artemis-mqtt-protocol/src/main/java/org/apache/activemq/artemis/core/protocol/mqtt/MQTTLogger.java b/artemis-protocols/artemis-mqtt-protocol/src/main/java/org/apache/activemq/artemis/core/protocol/mqtt/MQTTLogger.java
index 0a8f24b..6998ca6 100644
--- a/artemis-protocols/artemis-mqtt-protocol/src/main/java/org/apache/activemq/artemis/core/protocol/mqtt/MQTTLogger.java
+++ b/artemis-protocols/artemis-mqtt-protocol/src/main/java/org/apache/activemq/artemis/core/protocol/mqtt/MQTTLogger.java
@@ -24,7 +24,7 @@ import org.jboss.logging.annotations.MessageLogger;
 /**
  * Logger Code 83
  *
- * each message id must be 6 digits long starting with 10, the 3rd digit donates the level so
+ * each message id must be 6 digits long starting with 83, the 3rd digit donates the level so
  *
  * INF0  1
  * WARN  2

http://git-wip-us.apache.org/repos/asf/activemq-artemis/blob/b3529dce/artemis-protocols/artemis-stomp-protocol/src/main/java/org/apache/activemq/artemis/core/protocol/stomp/ActiveMQStompProtocolLogger.java
----------------------------------------------------------------------
diff --git a/artemis-protocols/artemis-stomp-protocol/src/main/java/org/apache/activemq/artemis/core/protocol/stomp/ActiveMQStompProtocolLogger.java b/artemis-protocols/artemis-stomp-protocol/src/main/java/org/apache/activemq/artemis/core/protocol/stomp/ActiveMQStompProtocolLogger.java
index e9c431b..6ca9da9 100644
--- a/artemis-protocols/artemis-stomp-protocol/src/main/java/org/apache/activemq/artemis/core/protocol/stomp/ActiveMQStompProtocolLogger.java
+++ b/artemis-protocols/artemis-stomp-protocol/src/main/java/org/apache/activemq/artemis/core/protocol/stomp/ActiveMQStompProtocolLogger.java
@@ -24,9 +24,9 @@ import org.jboss.logging.annotations.Message;
 import org.jboss.logging.annotations.MessageLogger;
 
 /**
- * Logger Code 22
+ * Logger Code 33
  *
- * each message id must be 6 digits long starting with 22, the 3rd digit donates the level so
+ * each message id must be 6 digits long starting with 33, the 3rd digit donates the level so
  *
  * INF0  1
  * WARN  2
@@ -35,7 +35,7 @@ import org.jboss.logging.annotations.MessageLogger;
  * TRACE 5
  * FATAL 6
  *
- * so an INFO message would be 241000 to 246999
+ * so an INFO message would be 331000 to 331999
  */
 
 @MessageLogger(projectCode = "AMQ")
@@ -47,14 +47,14 @@ public interface ActiveMQStompProtocolLogger extends BasicLogger {
    ActiveMQStompProtocolLogger LOGGER = Logger.getMessageLogger(ActiveMQStompProtocolLogger.class, ActiveMQStompProtocolLogger.class.getPackage().getName());
 
    @LogMessage(level = Logger.Level.WARN)
-   @Message(id = 222068, value = "connection closed {0}", format = Message.Format.MESSAGE_FORMAT)
+   @Message(id = 332068, value = "connection closed {0}", format = Message.Format.MESSAGE_FORMAT)
    void connectionClosed(StompConnection connection);
 
    @LogMessage(level = Logger.Level.WARN)
-   @Message(id = 222069, value = "Sent ERROR frame to STOMP client {0}: {1}", format = Message.Format.MESSAGE_FORMAT)
+   @Message(id = 332069, value = "Sent ERROR frame to STOMP client {0}: {1}", format = Message.Format.MESSAGE_FORMAT)
    void sentErrorToClient(String address, String message);
 
    @LogMessage(level = Logger.Level.ERROR)
-   @Message(id = 224023, value = "Unable to send frame {0}", format = Message.Format.MESSAGE_FORMAT)
+   @Message(id = 334023, value = "Unable to send frame {0}", format = Message.Format.MESSAGE_FORMAT)
    void errorSendingFrame(@Cause Exception e, StompFrame frame);
 }

http://git-wip-us.apache.org/repos/asf/activemq-artemis/blob/b3529dce/artemis-protocols/artemis-stomp-protocol/src/main/java/org/apache/activemq/artemis/core/protocol/stomp/ActiveMQStompProtocolMessageBundle.java
----------------------------------------------------------------------
diff --git a/artemis-protocols/artemis-stomp-protocol/src/main/java/org/apache/activemq/artemis/core/protocol/stomp/ActiveMQStompProtocolMessageBundle.java b/artemis-protocols/artemis-stomp-protocol/src/main/java/org/apache/activemq/artemis/core/protocol/stomp/ActiveMQStompProtocolMessageBundle.java
index d377abd..d920fd3 100644
--- a/artemis-protocols/artemis-stomp-protocol/src/main/java/org/apache/activemq/artemis/core/protocol/stomp/ActiveMQStompProtocolMessageBundle.java
+++ b/artemis-protocols/artemis-stomp-protocol/src/main/java/org/apache/activemq/artemis/core/protocol/stomp/ActiveMQStompProtocolMessageBundle.java
@@ -24,7 +24,7 @@ import org.jboss.logging.annotations.MessageBundle;
 /**
  * Logger Code 33
  * <p>
- * Each message id must be 6 digits long starting with 10, the 3rd digit should be 9. So the range
+ * Each message id must be 6 digits long starting with 33, the 3rd digit should be 9. So the range
  * is from 339000 to 339999.
  * <p>
  * Once released, methods should not be deleted as they may be referenced by knowledge base

http://git-wip-us.apache.org/repos/asf/activemq-artemis/blob/b3529dce/artemis-server-osgi/src/main/java/org/apache/activemq/artemis/osgi/ActiveMQOsgiLogger.java
----------------------------------------------------------------------
diff --git a/artemis-server-osgi/src/main/java/org/apache/activemq/artemis/osgi/ActiveMQOsgiLogger.java b/artemis-server-osgi/src/main/java/org/apache/activemq/artemis/osgi/ActiveMQOsgiLogger.java
index c51373d..a169457 100644
--- a/artemis-server-osgi/src/main/java/org/apache/activemq/artemis/osgi/ActiveMQOsgiLogger.java
+++ b/artemis-server-osgi/src/main/java/org/apache/activemq/artemis/osgi/ActiveMQOsgiLogger.java
@@ -26,7 +26,7 @@ import org.jboss.logging.annotations.MessageLogger;
 /**
  * Logger code 58
  *
- * each message id must be 6 digits long starting with 57, the 3rd digit donates the level so
+ * each message id must be 6 digits long starting with 58, the 3rd digit donates the level so
  *
  * INF0  1
  * WARN  2

http://git-wip-us.apache.org/repos/asf/activemq-artemis/blob/b3529dce/artemis-server/src/main/java/org/apache/activemq/artemis/core/server/ActiveMQMessageBundle.java
----------------------------------------------------------------------
diff --git a/artemis-server/src/main/java/org/apache/activemq/artemis/core/server/ActiveMQMessageBundle.java b/artemis-server/src/main/java/org/apache/activemq/artemis/core/server/ActiveMQMessageBundle.java
index d923ddc..c797710 100644
--- a/artemis-server/src/main/java/org/apache/activemq/artemis/core/server/ActiveMQMessageBundle.java
+++ b/artemis-server/src/main/java/org/apache/activemq/artemis/core/server/ActiveMQMessageBundle.java
@@ -53,10 +53,10 @@ import org.jboss.logging.annotations.Message;
 import org.jboss.logging.annotations.MessageBundle;
 
 /**
- * Logger Code 11
+ * Logger Code 22
  * <p>
- * Each message id must be 6 digits long starting with 10, the 3rd digit should be 9. So the range
- * is from 119000 to 119999.
+ * Each message id must be 6 digits long starting with 22, the 3rd digit should be 9. So the range
+ * is from 229000 to 229999.
  * <p>
  * Once released, methods should not be deleted as they may be referenced by knowledge base
  * articles. Unused methods should be marked as deprecated.
@@ -66,376 +66,376 @@ public interface ActiveMQMessageBundle {
 
    ActiveMQMessageBundle BUNDLE = Messages.getBundle(ActiveMQMessageBundle.class);
 
-   @Message(id = 119000, value = "Activation for server {0}", format = Message.Format.MESSAGE_FORMAT)
+   @Message(id = 229000, value = "Activation for server {0}", format = Message.Format.MESSAGE_FORMAT)
    String activationForServer(ActiveMQServer server);
 
-   @Message(id = 119001, value = "Generating thread dump", format = Message.Format.MESSAGE_FORMAT)
+   @Message(id = 229001, value = "Generating thread dump", format = Message.Format.MESSAGE_FORMAT)
    String generatingThreadDump();
 
-   @Message(id = 119002, value = "Thread {0} name = {1} id = {2} group = {3}", format = Message.Format.MESSAGE_FORMAT)
+   @Message(id = 229002, value = "Thread {0} name = {1} id = {2} group = {3}", format = Message.Format.MESSAGE_FORMAT)
    String threadDump(Thread key, String name, Long id, ThreadGroup threadGroup);
 
-   @Message(id = 119003, value = "End Thread dump")
+   @Message(id = 229003, value = "End Thread dump")
    String endThreadDump();
 
-   @Message(id = 119004, value = "Information about server {0}\nCluster Connection:{1}", format = Message.Format.MESSAGE_FORMAT)
+   @Message(id = 229004, value = "Information about server {0}\nCluster Connection:{1}", format = Message.Format.MESSAGE_FORMAT)
    String serverDescribe(String identity, String describe);
 
-   @Message(id = 119005, value = "connections for {0} closed by management", format = Message.Format.MESSAGE_FORMAT)
+   @Message(id = 229005, value = "connections for {0} closed by management", format = Message.Format.MESSAGE_FORMAT)
    ActiveMQInternalErrorException connectionsClosedByManagement(String ipAddress);
 
-   @Message(id = 119006, value = "journals are not JournalImpl. You can''t set a replicator!")
+   @Message(id = 229006, value = "journals are not JournalImpl. You can''t set a replicator!")
    ActiveMQInternalErrorException notJournalImpl();
 
-   @Message(id = 119007, value = "unhandled error during replication")
+   @Message(id = 229007, value = "unhandled error during replication")
    ActiveMQInternalErrorException replicationUnhandledError(@Cause Exception e);
 
-   @Message(id = 119008, value = "Live Node contains more journals than the backup node. Probably a version match error")
+   @Message(id = 229008, value = "Live Node contains more journals than the backup node. Probably a version match error")
    ActiveMQInternalErrorException replicationTooManyJournals();
 
-   @Message(id = 119009, value = "Unhandled file type {0}", format = Message.Format.MESSAGE_FORMAT)
+   @Message(id = 229009, value = "Unhandled file type {0}", format = Message.Format.MESSAGE_FORMAT)
    ActiveMQInternalErrorException replicationUnhandledFileType(ReplicationSyncFileMessage.FileType fileType);
 
-   @Message(id = 119010, value = "Remote Backup can not be up-to-date!")
+   @Message(id = 229010, value = "Remote Backup can not be up-to-date!")
    ActiveMQInternalErrorException replicationBackupUpToDate();
 
-   @Message(id = 119011, value = "unhandled data type!")
+   @Message(id = 229011, value = "unhandled data type!")
    ActiveMQInternalErrorException replicationUnhandledDataType();
 
-   @Message(id = 119012, value = "No binding for divert {0}", format = Message.Format.MESSAGE_FORMAT)
+   @Message(id = 229012, value = "No binding for divert {0}", format = Message.Format.MESSAGE_FORMAT)
    ActiveMQInternalErrorException noBindingForDivert(SimpleString name);
 
-   @Message(id = 119013, value = "Binding {0} is not a divert", format = Message.Format.MESSAGE_FORMAT)
+   @Message(id = 229013, value = "Binding {0} is not a divert", format = Message.Format.MESSAGE_FORMAT)
    ActiveMQInternalErrorException bindingNotDivert(SimpleString name);
 
-   @Message(id = 119014,
+   @Message(id = 229014,
       value = "Did not receive data from {0} within the {1}ms connection TTL. The connection will now be closed.", format = Message.Format.MESSAGE_FORMAT)
    ActiveMQConnectionTimedOutException clientExited(String remoteAddress, long ttl);
 
-   @Message(id = 119015, value = "Must specify a name for each divert. This one will not be deployed.", format = Message.Format.MESSAGE_FORMAT)
+   @Message(id = 229015, value = "Must specify a name for each divert. This one will not be deployed.", format = Message.Format.MESSAGE_FORMAT)
    ActiveMQInternalErrorException divertWithNoName();
 
-   @Message(id = 119017, value = "Queue {0} does not exist", format = Message.Format.MESSAGE_FORMAT)
+   @Message(id = 229017, value = "Queue {0} does not exist", format = Message.Format.MESSAGE_FORMAT)
    ActiveMQNonExistentQueueException noSuchQueue(SimpleString queueName);
 
-   @Message(id = 119018, value = "Binding already exists {0}", format = Message.Format.MESSAGE_FORMAT)
+   @Message(id = 229018, value = "Binding already exists {0}", format = Message.Format.MESSAGE_FORMAT)
    ActiveMQQueueExistsException bindingAlreadyExists(Binding binding);
 
-   @Message(id = 119019, value = "Queue {0} already exists on address {1}", format = Message.Format.MESSAGE_FORMAT)
+   @Message(id = 229019, value = "Queue {0} already exists on address {1}", format = Message.Format.MESSAGE_FORMAT)
    ActiveMQQueueExistsException queueAlreadyExists(SimpleString queueName, SimpleString addressName);
 
-   @Message(id = 119020, value = "Invalid filter: {0}", format = Message.Format.MESSAGE_FORMAT)
+   @Message(id = 229020, value = "Invalid filter: {0}", format = Message.Format.MESSAGE_FORMAT)
    ActiveMQInvalidFilterExpressionException invalidFilter(@Cause Throwable e, SimpleString filter);
 
-   @Message(id = 119021, value = "MessageId was not assigned to Message")
+   @Message(id = 229021, value = "MessageId was not assigned to Message")
    ActiveMQIllegalStateException messageIdNotAssigned();
 
-   @Message(id = 119022, value = "Cannot compare journals if not in sync!")
+   @Message(id = 229022, value = "Cannot compare journals if not in sync!")
    ActiveMQIllegalStateException journalsNotInSync();
 
-   @Message(id = 119023, value = "Connected server is not a backup server")
+   @Message(id = 229023, value = "Connected server is not a backup server")
    ActiveMQIllegalStateException serverNotBackupServer();
 
-   @Message(id = 119024, value = "Backup replication server is already connected to another server")
+   @Message(id = 229024, value = "Backup replication server is already connected to another server")
    ActiveMQIllegalStateException alreadyHaveReplicationServer();
 
-   @Message(id = 119025, value = "Cannot delete queue {0} on binding {1} - it has consumers = {2}", format = Message.Format.MESSAGE_FORMAT)
+   @Message(id = 229025, value = "Cannot delete queue {0} on binding {1} - it has consumers = {2}", format = Message.Format.MESSAGE_FORMAT)
    ActiveMQIllegalStateException cannotDeleteQueue(SimpleString name, SimpleString queueName, String s);
 
-   @Message(id = 119026, value = "Backup Server was not yet in sync with live")
+   @Message(id = 229026, value = "Backup Server was not yet in sync with live")
    ActiveMQIllegalStateException backupServerNotInSync();
 
-   @Message(id = 119027, value = "Could not find reference on consumer ID={0}, messageId = {1} queue = {2}", format = Message.Format.MESSAGE_FORMAT)
+   @Message(id = 229027, value = "Could not find reference on consumer ID={0}, messageId = {1} queue = {2}", format = Message.Format.MESSAGE_FORMAT)
    ActiveMQIllegalStateException consumerNoReference(Long id, Long messageID, SimpleString name);
 
-   @Message(id = 119028, value = "Consumer {0} doesn''t exist on the server", format = Message.Format.MESSAGE_FORMAT)
+   @Message(id = 229028, value = "Consumer {0} doesn''t exist on the server", format = Message.Format.MESSAGE_FORMAT)
    ActiveMQIllegalStateException consumerDoesntExist(long consumerID);
 
-   @Message(id = 119029, value = "No address configured on the Server''s Session")
+   @Message(id = 229029, value = "No address configured on the Server''s Session")
    ActiveMQIllegalStateException noAddress();
 
-   @Message(id = 119030, value = "large-message not initialized on server")
+   @Message(id = 229030, value = "large-message not initialized on server")
    ActiveMQIllegalStateException largeMessageNotInitialised();
 
-   @Message(id = 119031, value = "Unable to validate user from {0}. Username: {1}; SSL certificate subject DN: {2}", format = Message.Format.MESSAGE_FORMAT)
+   @Message(id = 229031, value = "Unable to validate user from {0}. Username: {1}; SSL certificate subject DN: {2}", format = Message.Format.MESSAGE_FORMAT)
    ActiveMQSecurityException unableToValidateUser(String remoteAddress, String user, String certMessage);
 
-   @Message(id = 119032, value = "User: {0} does not have permission=''{1}'' on address {2}", format = Message.Format.MESSAGE_FORMAT)
+   @Message(id = 229032, value = "User: {0} does not have permission=''{1}'' on address {2}", format = Message.Format.MESSAGE_FORMAT)
    ActiveMQSecurityException userNoPermissions(String username, CheckType checkType, String saddress);
 
-   @Message(id = 119033, value = "Server and client versions incompatible")
+   @Message(id = 229033, value = "Server and client versions incompatible")
    ActiveMQIncompatibleClientServerException incompatibleClientServer();
 
-   @Message(id = 119034, value = "Server not started")
+   @Message(id = 229034, value = "Server not started")
    ActiveMQSessionCreationException serverNotStarted();
 
-   @Message(id = 119035, value = "Metadata {0}={1} had been set already", format = Message.Format.MESSAGE_FORMAT)
+   @Message(id = 229035, value = "Metadata {0}={1} had been set already", format = Message.Format.MESSAGE_FORMAT)
    ActiveMQDuplicateMetaDataException duplicateMetadata(String key, String data);
 
-   @Message(id = 119036, value = "Invalid type: {0}", format = Message.Format.MESSAGE_FORMAT)
+   @Message(id = 229036, value = "Invalid type: {0}", format = Message.Format.MESSAGE_FORMAT)
    IllegalArgumentException invalidType(Object type);
 
-   @Message(id = 119038, value = "{0} must neither be null nor empty", format = Message.Format.MESSAGE_FORMAT)
+   @Message(id = 229038, value = "{0} must neither be null nor empty", format = Message.Format.MESSAGE_FORMAT)
    IllegalArgumentException emptyOrNull(String name);
 
-   @Message(id = 119039, value = "{0}  must be greater than 0 (actual value: {1})", format = Message.Format.MESSAGE_FORMAT)
+   @Message(id = 229039, value = "{0}  must be greater than 0 (actual value: {1})", format = Message.Format.MESSAGE_FORMAT)
    IllegalArgumentException greaterThanZero(String name, Number val);
 
-   @Message(id = 119040, value = "{0} must be a valid percentual value between 0 and 100 (actual value: {1})", format = Message.Format.MESSAGE_FORMAT)
+   @Message(id = 229040, value = "{0} must be a valid percentual value between 0 and 100 (actual value: {1})", format = Message.Format.MESSAGE_FORMAT)
    IllegalArgumentException notPercent(String name, Number val);
 
-   @Message(id = 119041, value = "{0}  must be equals to -1 or greater than 0 (actual value: {1})", format = Message.Format.MESSAGE_FORMAT)
+   @Message(id = 229041, value = "{0}  must be equals to -1 or greater than 0 (actual value: {1})", format = Message.Format.MESSAGE_FORMAT)
    IllegalArgumentException greaterThanMinusOne(String name, Number val);
 
-   @Message(id = 119042, value = "{0}  must be equals to -1 or greater or equals to 0 (actual value: {1})", format = Message.Format.MESSAGE_FORMAT)
+   @Message(id = 229042, value = "{0}  must be equals to -1 or greater or equals to 0 (actual value: {1})", format = Message.Format.MESSAGE_FORMAT)
    IllegalArgumentException greaterThanZeroOrMinusOne(String name, Number val);
 
-   @Message(id = 119043, value = "{0} must be between {1} and {2} inclusive (actual value: {3})", format = Message.Format.MESSAGE_FORMAT)
+   @Message(id = 229043, value = "{0} must be between {1} and {2} inclusive (actual value: {3})", format = Message.Format.MESSAGE_FORMAT)
    IllegalArgumentException mustbeBetween(String name, Integer minPriority, Integer maxPriority, Object value);
 
-   @Message(id = 119044, value = "Invalid journal type {0}", format = Message.Format.MESSAGE_FORMAT)
+   @Message(id = 229044, value = "Invalid journal type {0}", format = Message.Format.MESSAGE_FORMAT)
    IllegalArgumentException invalidJournalType(String val);
 
-   @Message(id = 119045, value = "Invalid address full message policy type {0}", format = Message.Format.MESSAGE_FORMAT)
+   @Message(id = 229045, value = "Invalid address full message policy type {0}", format = Message.Format.MESSAGE_FORMAT)
    IllegalArgumentException invalidAddressFullPolicyType(String val);
 
-   @Message(id = 119046, value = "invalid value: {0} count must be greater than 0", format = Message.Format.MESSAGE_FORMAT)
+   @Message(id = 229046, value = "invalid value: {0} count must be greater than 0", format = Message.Format.MESSAGE_FORMAT)
    IllegalArgumentException greaterThanZero(Integer count);
 
-   @Message(id = 119047, value = "invalid value: {0} sample period must be greater than 0", format = Message.Format.MESSAGE_FORMAT)
+   @Message(id = 229047, value = "invalid value: {0} sample period must be greater than 0", format = Message.Format.MESSAGE_FORMAT)
    IllegalArgumentException periodMustGreaterThanZero(Long newPeriod);
 
-   @Message(id = 119048, value = "invalid new Priority value: {0}. It must be between 0 and 9 (both included)", format = Message.Format.MESSAGE_FORMAT)
+   @Message(id = 229048, value = "invalid new Priority value: {0}. It must be between 0 and 9 (both included)", format = Message.Format.MESSAGE_FORMAT)
    IllegalArgumentException invalidNewPriority(Integer period);
 
-   @Message(id = 119049, value = "No queue found for {0}", format = Message.Format.MESSAGE_FORMAT)
+   @Message(id = 229049, value = "No queue found for {0}", format = Message.Format.MESSAGE_FORMAT)
    IllegalArgumentException noQueueFound(String otherQueueName);
 
-   @Message(id = 119050, value = "Only NIO and AsyncIO are supported journals")
+   @Message(id = 229050, value = "Only NIO and AsyncIO are supported journals")
    IllegalArgumentException invalidJournal();
 
-   @Message(id = 119051, value = "Invalid journal type {0}", format = Message.Format.MESSAGE_FORMAT)
+   @Message(id = 229051, value = "Invalid journal type {0}", format = Message.Format.MESSAGE_FORMAT)
    IllegalArgumentException invalidJournalType2(JournalType journalType);
 
-   @Message(id = 119052, value = "Directory {0} does not exist and cannot be created", format = Message.Format.MESSAGE_FORMAT)
+   @Message(id = 229052, value = "Directory {0} does not exist and cannot be created", format = Message.Format.MESSAGE_FORMAT)
    IllegalArgumentException cannotCreateDir(String dir);
 
-   @Message(id = 119054, value = "Cannot convert to int")
+   @Message(id = 229054, value = "Cannot convert to int")
    IllegalArgumentException cannotConvertToInt();
 
-   @Message(id = 119055, value = "Routing name is null")
+   @Message(id = 229055, value = "Routing name is null")
    IllegalArgumentException routeNameIsNull();
 
-   @Message(id = 119056, value = "Cluster name is null")
+   @Message(id = 229056, value = "Cluster name is null")
    IllegalArgumentException clusterNameIsNull();
 
-   @Message(id = 119057, value = "Address is null")
+   @Message(id = 229057, value = "Address is null")
    IllegalArgumentException addressIsNull();
 
-   @Message(id = 119058, value = "Binding type not specified")
+   @Message(id = 229058, value = "Binding type not specified")
    IllegalArgumentException bindingTypeNotSpecified();
 
-   @Message(id = 119059, value = "Binding ID is null")
+   @Message(id = 229059, value = "Binding ID is null")
    IllegalArgumentException bindingIdNotSpecified();
 
-   @Message(id = 119060, value = "Distance is null")
+   @Message(id = 229060, value = "Distance is null")
    IllegalArgumentException distancenotSpecified();
 
-   @Message(id = 119061, value = "Connection already exists with id {0}", format = Message.Format.MESSAGE_FORMAT)
+   @Message(id = 229061, value = "Connection already exists with id {0}", format = Message.Format.MESSAGE_FORMAT)
    IllegalArgumentException connectionExists(Object id);
 
-   @Message(id = 119062, value = "Acceptor with id {0} already registered", format = Message.Format.MESSAGE_FORMAT)
+   @Message(id = 229062, value = "Acceptor with id {0} already registered", format = Message.Format.MESSAGE_FORMAT)
    IllegalArgumentException acceptorExists(Integer id);
 
-   @Message(id = 119063, value = "Acceptor with id {0} not registered", format = Message.Format.MESSAGE_FORMAT)
+   @Message(id = 229063, value = "Acceptor with id {0} not registered", format = Message.Format.MESSAGE_FORMAT)
    IllegalArgumentException acceptorNotExists(Integer id);
 
-   @Message(id = 119064, value = "Unknown protocol {0}", format = Message.Format.MESSAGE_FORMAT)
+   @Message(id = 229064, value = "Unknown protocol {0}", format = Message.Format.MESSAGE_FORMAT)
    IllegalArgumentException unknownProtocol(String protocol);
 
-   @Message(id = 119065, value = "node id is null")
+   @Message(id = 229065, value = "node id is null")
    IllegalArgumentException nodeIdNull();
 
-   @Message(id = 119066, value = "Queue name is null")
+   @Message(id = 229066, value = "Queue name is null")
    IllegalArgumentException queueNameIsNull();
 
-   @Message(id = 119067, value = "Cannot find resource with name {0}", format = Message.Format.MESSAGE_FORMAT)
+   @Message(id = 229067, value = "Cannot find resource with name {0}", format = Message.Format.MESSAGE_FORMAT)
    IllegalArgumentException cannotFindResource(String resourceName);
 
-   @Message(id = 119068, value = "no getter method for {0}", format = Message.Format.MESSAGE_FORMAT)
+   @Message(id = 229068, value = "no getter method for {0}", format = Message.Format.MESSAGE_FORMAT)
    IllegalArgumentException noGetterMethod(String resourceName);
 
-   @Message(id = 119069, value = "no operation {0}/{1}", format = Message.Format.MESSAGE_FORMAT)
+   @Message(id = 229069, value = "no operation {0}/{1}", format = Message.Format.MESSAGE_FORMAT)
    IllegalArgumentException noOperation(String operation, Integer length);
 
-   @Message(id = 119070, value = "match can not be null")
+   @Message(id = 229070, value = "match can not be null")
    IllegalArgumentException nullMatch();
 
-   @Message(id = 119071, value = "# can only be at end of match")
+   @Message(id = 229071, value = "# can only be at end of match")
    IllegalArgumentException invalidMatch();
 
-   @Message(id = 119072, value = "User cannot be null")
+   @Message(id = 229072, value = "User cannot be null")
    IllegalArgumentException nullUser();
 
-   @Message(id = 119073, value = "Password cannot be null")
+   @Message(id = 229073, value = "Password cannot be null")
    IllegalArgumentException nullPassword();
 
-   @Message(id = 119074, value = "Error instantiating transformer class {0}", format = Message.Format.MESSAGE_FORMAT)
+   @Message(id = 229074, value = "Error instantiating transformer class {0}", format = Message.Format.MESSAGE_FORMAT)
    IllegalArgumentException errorCreatingTransformerClass(@Cause Exception e, String transformerClassName);
 
-   @Message(id = 119075, value = "method autoEncode doesn''t know how to convert {0} yet", format = Message.Format.MESSAGE_FORMAT)
+   @Message(id = 229075, value = "method autoEncode doesn''t know how to convert {0} yet", format = Message.Format.MESSAGE_FORMAT)
    IllegalArgumentException autoConvertError(Class<? extends Object> aClass);
 
    /**
     * Message used on on {@link org.apache.activemq.artemis.core.server.impl.ActiveMQServerImpl#destroyConnectionWithSessionMetadata(String, String)}
     */
-   @Message(id = 119076, value = "Executing destroyConnection with {0}={1} through management''s request", format = Message.Format.MESSAGE_FORMAT)
+   @Message(id = 229076, value = "Executing destroyConnection with {0}={1} through management''s request", format = Message.Format.MESSAGE_FORMAT)
    String destroyConnectionWithSessionMetadataHeader(String key, String value);
 
    /**
     * Message used on on {@link org.apache.activemq.artemis.core.server.impl.ActiveMQServerImpl#destroyConnectionWithSessionMetadata(String, String)}
     */
-   @Message(id = 119077, value = "Closing connection {0}", format = Message.Format.MESSAGE_FORMAT)
+   @Message(id = 229077, value = "Closing connection {0}", format = Message.Format.MESSAGE_FORMAT)
    String destroyConnectionWithSessionMetadataClosingConnection(String serverSessionString);
 
    /**
     * Exception used on on {@link org.apache.activemq.artemis.core.server.impl.ActiveMQServerImpl#destroyConnectionWithSessionMetadata(String, String)}
     */
-   @Message(id = 119078, value = "Disconnected per admin''s request on {0}={1}", format = Message.Format.MESSAGE_FORMAT)
+   @Message(id = 229078, value = "Disconnected per admin''s request on {0}={1}", format = Message.Format.MESSAGE_FORMAT)
    ActiveMQDisconnectedException destroyConnectionWithSessionMetadataSendException(String key, String value);
 
    /**
     * Message used on on {@link org.apache.activemq.artemis.core.server.impl.ActiveMQServerImpl#destroyConnectionWithSessionMetadata(String, String)}
     */
-   @Message(id = 119079, value = "No session found with {0}={1}", format = Message.Format.MESSAGE_FORMAT)
+   @Message(id = 229079, value = "No session found with {0}={1}", format = Message.Format.MESSAGE_FORMAT)
    String destroyConnectionWithSessionMetadataNoSessionFound(String key, String value);
 
-   @Message(id = 119080, value = "Invalid Page IO, PagingManager was stopped or closed")
+   @Message(id = 229080, value = "Invalid Page IO, PagingManager was stopped or closed")
    ActiveMQIllegalStateException invalidPageIO();
 
-   @Message(id = 119081, value = "No Discovery Group configuration named {0} found", format = Message.Format.MESSAGE_FORMAT)
+   @Message(id = 229081, value = "No Discovery Group configuration named {0} found", format = Message.Format.MESSAGE_FORMAT)
    ActiveMQException noDiscoveryGroupFound(DiscoveryGroupConfiguration dg);
 
-   @Message(id = 119082, value = "Queue {0} already exists on another subscription", format = Message.Format.MESSAGE_FORMAT)
+   @Message(id = 229082, value = "Queue {0} already exists on another subscription", format = Message.Format.MESSAGE_FORMAT)
    ActiveMQInvalidTransientQueueUseException queueSubscriptionBelongsToDifferentAddress(SimpleString queueName);
 
-   @Message(id = 119083, value = "Queue {0} has a different filter than requested", format = Message.Format.MESSAGE_FORMAT)
+   @Message(id = 229083, value = "Queue {0} has a different filter than requested", format = Message.Format.MESSAGE_FORMAT)
    ActiveMQInvalidTransientQueueUseException queueSubscriptionBelongsToDifferentFilter(SimpleString queueName);
 
    // this code has to match with version 2.3.x as it's used on integration tests at Wildfly and JBoss EAP
-   @Message(id = 119099, value = "Unable to authenticate cluster user: {0}",
+   @Message(id = 229099, value = "Unable to authenticate cluster user: {0}",
       format = Message.Format.MESSAGE_FORMAT)
    ActiveMQClusterSecurityException unableToValidateClusterUser(String user);
 
-   @Message(id = 119100, value = "Trying to move a journal file that refers to a file instead of a directory: {0}",
+   @Message(id = 229100, value = "Trying to move a journal file that refers to a file instead of a directory: {0}",
       format = Message.Format.MESSAGE_FORMAT)
    IllegalStateException journalDirIsFile(File fDir);
 
-   @Message(id = 119101, value = "error trying to backup journal files at directory: {0}",
+   @Message(id = 229101, value = "error trying to backup journal files at directory: {0}",
       format = Message.Format.MESSAGE_FORMAT)
    IllegalStateException couldNotMoveJournal(File dir);
 
-   @Message(id = 119102, value = "Address \"{0}\" is full.", format = Message.Format.MESSAGE_FORMAT)
+   @Message(id = 229102, value = "Address \"{0}\" is full.", format = Message.Format.MESSAGE_FORMAT)
    ActiveMQAddressFullException addressIsFull(String addressName);
 
-   @Message(id = 119103, value = "No Connectors or Discovery Groups configured for Scale Down")
+   @Message(id = 229103, value = "No Connectors or Discovery Groups configured for Scale Down")
    ActiveMQException noConfigurationFoundForScaleDown();
 
-   @Message(id = 119104, value = "Server is stopping. Message grouping not allowed")
+   @Message(id = 229104, value = "Server is stopping. Message grouping not allowed")
    ActiveMQException groupWhileStopping();
 
-   @Message(id = 119106, value = "Invalid slow consumer policy type {0}", format = Message.Format.MESSAGE_FORMAT)
+   @Message(id = 229106, value = "Invalid slow consumer policy type {0}", format = Message.Format.MESSAGE_FORMAT)
    IllegalArgumentException invalidSlowConsumerPolicyType(String val);
 
-   @Message(id = 119107, value = "consumer connections for address {0} closed by management", format = Message.Format.MESSAGE_FORMAT)
+   @Message(id = 229107, value = "consumer connections for address {0} closed by management", format = Message.Format.MESSAGE_FORMAT)
    ActiveMQInternalErrorException consumerConnectionsClosedByManagement(String address);
 
-   @Message(id = 119108, value = "connections for user {0} closed by management", format = Message.Format.MESSAGE_FORMAT)
+   @Message(id = 229108, value = "connections for user {0} closed by management", format = Message.Format.MESSAGE_FORMAT)
    ActiveMQInternalErrorException connectionsForUserClosedByManagement(String userName);
 
-   @Message(id = 119109, value = "unsupported HA Policy Configuration {0}", format = Message.Format.MESSAGE_FORMAT)
+   @Message(id = 229109, value = "unsupported HA Policy Configuration {0}", format = Message.Format.MESSAGE_FORMAT)
    ActiveMQIllegalStateException unsupportedHAPolicyConfiguration(Object o);
 
-   @Message(id = 119110, value = "Too many sessions for user ''{0}''. Sessions allowed: {1}.", format = Message.Format.MESSAGE_FORMAT)
+   @Message(id = 229110, value = "Too many sessions for user ''{0}''. Sessions allowed: {1}.", format = Message.Format.MESSAGE_FORMAT)
    ActiveMQSessionCreationException sessionLimitReached(String username, int limit);
 
-   @Message(id = 119111, value = "Too many queues created by user ''{0}''. Queues allowed: {1}.", format = Message.Format.MESSAGE_FORMAT)
+   @Message(id = 229111, value = "Too many queues created by user ''{0}''. Queues allowed: {1}.", format = Message.Format.MESSAGE_FORMAT)
    ActiveMQSessionCreationException queueLimitReached(String username, int limit);
 
-   @Message(id = 119112, value = "Cannot set MBeanServer during startup or while started")
+   @Message(id = 229112, value = "Cannot set MBeanServer during startup or while started")
    IllegalStateException cannotSetMBeanserver();
 
-   @Message(id = 119113, value = "Invalid message load balancing type {0}", format = Message.Format.MESSAGE_FORMAT)
+   @Message(id = 229113, value = "Invalid message load balancing type {0}", format = Message.Format.MESSAGE_FORMAT)
    IllegalArgumentException invalidMessageLoadBalancingType(String val);
 
-   @Message(id = 119114, value = "Replication synchronization process timed out after waiting {0} milliseconds", format = Message.Format.MESSAGE_FORMAT)
+   @Message(id = 229114, value = "Replication synchronization process timed out after waiting {0} milliseconds", format = Message.Format.MESSAGE_FORMAT)
    IllegalStateException replicationSynchronizationTimeout(long timeout);
 
-   @Message(id = 119115, value = "Colocated Policy hasn''t different type live and backup", format = Message.Format.MESSAGE_FORMAT)
+   @Message(id = 229115, value = "Colocated Policy hasn''t different type live and backup", format = Message.Format.MESSAGE_FORMAT)
    ActiveMQIllegalStateException liveBackupMismatch();
 
-   @Message(id = 119116, value = "Netty Acceptor unavailable", format = Message.Format.MESSAGE_FORMAT)
+   @Message(id = 229116, value = "Netty Acceptor unavailable", format = Message.Format.MESSAGE_FORMAT)
    IllegalStateException acceptorUnavailable();
 
-   @Message(id = 119117, value = "Replicator is null. Replication was likely terminated.")
+   @Message(id = 229117, value = "Replicator is null. Replication was likely terminated.")
    ActiveMQIllegalStateException replicatorIsNull();
 
-   @Message(id = 119118, value = "Management method not applicable for current server configuration")
+   @Message(id = 229118, value = "Management method not applicable for current server configuration")
    IllegalStateException methodNotApplicable();
 
-   @Message(id = 119119, value = "Disk Capacity is Low, cannot produce more messages.")
+   @Message(id = 229119, value = "Disk Capacity is Low, cannot produce more messages.")
    ActiveMQIOErrorException diskBeyondLimit();
 
-   @Message(id = 119120, value = "connection with ID {0} closed by management", format = Message.Format.MESSAGE_FORMAT)
+   @Message(id = 229120, value = "connection with ID {0} closed by management", format = Message.Format.MESSAGE_FORMAT)
    ActiveMQInternalErrorException connectionWithIDClosedByManagement(String ID);
 
-   @Message(id = 119200, value = "Maximum Consumer Limit Reached on Queue:(address={0},queue={1})", format = Message.Format.MESSAGE_FORMAT)
+   @Message(id = 229200, value = "Maximum Consumer Limit Reached on Queue:(address={0},queue={1})", format = Message.Format.MESSAGE_FORMAT)
    ActiveMQQueueMaxConsumerLimitReached maxConsumerLimitReachedForQueue(SimpleString address, SimpleString queueName);
 
-   @Message(id = 119201, value = "Expected Routing Type {1} but found {2} for address {0}", format = Message.Format.MESSAGE_FORMAT)
+   @Message(id = 229201, value = "Expected Routing Type {1} but found {2} for address {0}", format = Message.Format.MESSAGE_FORMAT)
    ActiveMQUnexpectedRoutingTypeForAddress unexpectedRoutingTypeForAddress(SimpleString address, RoutingType expectedRoutingType, Set<RoutingType> supportedRoutingTypes);
 
-   @Message(id = 119202, value = "Invalid Queue Configuration for Queue {0}, Address {1}.  Expected {2} to be {3} but was {4}", format = Message.Format.MESSAGE_FORMAT)
+   @Message(id = 229202, value = "Invalid Queue Configuration for Queue {0}, Address {1}.  Expected {2} to be {3} but was {4}", format = Message.Format.MESSAGE_FORMAT)
    ActiveMQInvalidQueueConfiguration invalidQueueConfiguration(SimpleString address, SimpleString queueName, String queuePropertyName, Object expectedValue, Object actualValue);
 
-   @Message(id = 119203, value = "Address Does Not Exist: {0}", format = Message.Format.MESSAGE_FORMAT)
+   @Message(id = 229203, value = "Address Does Not Exist: {0}", format = Message.Format.MESSAGE_FORMAT)
    ActiveMQAddressDoesNotExistException addressDoesNotExist(SimpleString address);
 
-   @Message(id = 119204, value = "Address already exists: {0}", format = Message.Format.MESSAGE_FORMAT)
+   @Message(id = 229204, value = "Address already exists: {0}", format = Message.Format.MESSAGE_FORMAT)
    ActiveMQAddressExistsException addressAlreadyExists(SimpleString address);
 
-   @Message(id = 119205, value = "Address {0} has bindings", format = Message.Format.MESSAGE_FORMAT)
+   @Message(id = 229205, value = "Address {0} has bindings", format = Message.Format.MESSAGE_FORMAT)
    ActiveMQDeleteAddressException addressHasBindings(SimpleString address);
 
-   @Message(id = 119206, value = "Queue {0} has invalid max consumer setting: {1}", format = Message.Format.MESSAGE_FORMAT)
+   @Message(id = 229206, value = "Queue {0} has invalid max consumer setting: {1}", format = Message.Format.MESSAGE_FORMAT)
    IllegalArgumentException invalidMaxConsumers(String queueName, int value);
 
-   @Message(id = 119207, value = "Can not create queue with routing type: {0}, Supported routing types for address: {1} are {2}", format = Message.Format.MESSAGE_FORMAT)
+   @Message(id = 229207, value = "Can not create queue with routing type: {0}, Supported routing types for address: {1} are {2}", format = Message.Format.MESSAGE_FORMAT)
    IllegalArgumentException invalidRoutingTypeForAddress(RoutingType routingType,
                                                          String address,
                                                          Set<RoutingType> supportedRoutingTypes);
 
-   @Message(id = 119208, value = "Invalid routing type {0}", format = Message.Format.MESSAGE_FORMAT)
+   @Message(id = 229208, value = "Invalid routing type {0}", format = Message.Format.MESSAGE_FORMAT)
    IllegalArgumentException invalidRoutingType(String val);
 
-   @Message(id = 119209, value = "Can''t remove routing type {0}, queues exists for address: {1}. Please delete queues before removing this routing type.", format = Message.Format.MESSAGE_FORMAT)
+   @Message(id = 229209, value = "Can''t remove routing type {0}, queues exists for address: {1}. Please delete queues before removing this routing type.", format = Message.Format.MESSAGE_FORMAT)
    IllegalStateException invalidRoutingTypeDelete(RoutingType routingType, String address);
 
-   @Message(id = 119210, value = "Can''t update queue {0} with maxConsumers: {1}. Current consumers are {2}.", format = Message.Format.MESSAGE_FORMAT)
+   @Message(id = 229210, value = "Can''t update queue {0} with maxConsumers: {1}. Current consumers are {2}.", format = Message.Format.MESSAGE_FORMAT)
    IllegalStateException invalidMaxConsumersUpdate(String queueName, int maxConsumers, int consumers);
 
-   @Message(id = 119211, value = "Can''t update queue {0} with routing type: {1}, Supported routing types for address: {2} are {3}", format = Message.Format.MESSAGE_FORMAT)
+   @Message(id = 229211, value = "Can''t update queue {0} with routing type: {1}, Supported routing types for address: {2} are {3}", format = Message.Format.MESSAGE_FORMAT)
    IllegalStateException invalidRoutingTypeUpdate(String queueName,
                                                   RoutingType routingType,
                                                   String address,
                                                   Set<RoutingType> supportedRoutingTypes);
 
-   @Message(id = 119212, value = "Invalid deletion policy type {0}", format = Message.Format.MESSAGE_FORMAT)
+   @Message(id = 229212, value = "Invalid deletion policy type {0}", format = Message.Format.MESSAGE_FORMAT)
    IllegalArgumentException invalidDeletionPolicyType(String val);
 
-   @Message(id = 119213, value = "User: {0} does not have permission=''{1}'' for queue {2} on address {3}", format = Message.Format.MESSAGE_FORMAT)
+   @Message(id = 229213, value = "User: {0} does not have permission=''{1}'' for queue {2} on address {3}", format = Message.Format.MESSAGE_FORMAT)
    ActiveMQSecurityException userNoPermissionsQueue(String username, CheckType checkType, String squeue, String saddress);
 
-   @Message(id = 119214, value = "{0} must be a valid percentage value between 0 and 100 or -1 (actual value: {1})", format = Message.Format.MESSAGE_FORMAT)
+   @Message(id = 229214, value = "{0} must be a valid percentage value between 0 and 100 or -1 (actual value: {1})", format = Message.Format.MESSAGE_FORMAT)
    IllegalArgumentException notPercentOrMinusOne(String name, Number val);
 }

http://git-wip-us.apache.org/repos/asf/activemq-artemis/blob/b3529dce/artemis-server/src/main/java/org/apache/activemq/artemis/core/server/ActiveMQServerLogger.java
----------------------------------------------------------------------
diff --git a/artemis-server/src/main/java/org/apache/activemq/artemis/core/server/ActiveMQServerLogger.java b/artemis-server/src/main/java/org/apache/activemq/artemis/core/server/ActiveMQServerLogger.java
index 65fd22d..20a6cfc 100644
--- a/artemis-server/src/main/java/org/apache/activemq/artemis/core/server/ActiveMQServerLogger.java
+++ b/artemis-server/src/main/java/org/apache/activemq/artemis/core/server/ActiveMQServerLogger.java
@@ -16,21 +16,6 @@
  */
 package org.apache.activemq.artemis.core.server;
 
-/**
- * Logger Code 22
- *
- * each message id must be 6 digits long starting with 10, the 3rd digit donates the level so
- *
- * INF0  1
- * WARN  2
- * DEBUG 3
- * ERROR 4
- * TRACE 5
- * FATAL 6
- *
- * so an INFO message would be 101000 to 101999
- */
-
 import javax.naming.NamingException;
 import javax.transaction.xa.Xid;
 import java.io.File;
@@ -69,6 +54,21 @@ import org.jboss.logging.annotations.Message;
 import org.jboss.logging.annotations.MessageLogger;
 import org.w3c.dom.Node;
 
+/**
+ * Logger Code 22
+ *
+ * each message id must be 6 digits long starting with 22, the 3rd digit donates the level so
+ *
+ * INF0  1
+ * WARN  2
+ * DEBUG 3
+ * ERROR 4
+ * TRACE 5
+ * FATAL 6
+ *
+ * so an INFO message would be 221000 to 221999
+ */
+
 @MessageLogger(projectCode = "AMQ")
 public interface ActiveMQServerLogger extends BasicLogger {
 

http://git-wip-us.apache.org/repos/asf/activemq-artemis/blob/b3529dce/artemis-service-extensions/src/main/java/org/apache/activemq/artemis/service/extensions/ActiveMQServiceExtensionLogger.java
----------------------------------------------------------------------
diff --git a/artemis-service-extensions/src/main/java/org/apache/activemq/artemis/service/extensions/ActiveMQServiceExtensionLogger.java b/artemis-service-extensions/src/main/java/org/apache/activemq/artemis/service/extensions/ActiveMQServiceExtensionLogger.java
index 3461bad..21aba23 100644
--- a/artemis-service-extensions/src/main/java/org/apache/activemq/artemis/service/extensions/ActiveMQServiceExtensionLogger.java
+++ b/artemis-service-extensions/src/main/java/org/apache/activemq/artemis/service/extensions/ActiveMQServiceExtensionLogger.java
@@ -24,9 +24,9 @@ import org.jboss.logging.annotations.Message;
 import org.jboss.logging.annotations.MessageLogger;
 
 /**
- * Logger Code 34
+ * Logger Code 35
  *
- * each message id must be 6 digits long starting with 20, the 3rd digit donates the level so
+ * each message id must be 6 digits long starting with 35, the 3rd digit donates the level so
  *
  * INF0  1
  * WARN  2
@@ -35,7 +35,7 @@ import org.jboss.logging.annotations.MessageLogger;
  * TRACE 5
  * FATAL 6
  *
- * so an INFO message would be 341000 to 341999
+ * so an INFO message would be 351000 to 351999
  */
 
 @MessageLogger(projectCode = "AMQ")
@@ -47,6 +47,6 @@ public interface ActiveMQServiceExtensionLogger extends BasicLogger {
    ActiveMQServiceExtensionLogger LOGGER = Logger.getMessageLogger(ActiveMQServiceExtensionLogger.class, ActiveMQServiceExtensionLogger.class.getPackage().getName());
 
    @LogMessage(level = Logger.Level.WARN)
-   @Message(id = 342000, value = "Attempted to locate a Transaction Manager but none found.", format = Message.Format.MESSAGE_FORMAT)
+   @Message(id = 352000, value = "Attempted to locate a Transaction Manager but none found.", format = Message.Format.MESSAGE_FORMAT)
    void transactionManagerNotFound();
 }
diff --git a/artemis-protocols/artemis-amqp-protocol/src/main/java/org/apache/activemq/artemis/protocol/amqp/logger/ActiveMQAMQPProtocolMessageBundle.java b/artemis-protocols/artemis-amqp-protocol/src/main/java/org/apache/activemq/artemis/protocol/amqp/logger/ActiveMQAMQPProtocolMessageBundle.java
index 12c17fc..10a6197 100644
--- a/artemis-protocols/artemis-amqp-protocol/src/main/java/org/apache/activemq/artemis/protocol/amqp/logger/ActiveMQAMQPProtocolMessageBundle.java
+++ b/artemis-protocols/artemis-amqp-protocol/src/main/java/org/apache/activemq/artemis/protocol/amqp/logger/ActiveMQAMQPProtocolMessageBundle.java
@@ -28,8 +28,8 @@ import org.jboss.logging.annotations.MessageBundle;
 /**
  * Logger Code 11
  * <p>
  * Each message id must be 6 digits long starting with 10, the 3rd digit should be 9. So the range
  * is from 219000 to 119999.
  * <p>
  * Once released, methods should not be deleted as they may be referenced by knowledge base
  * articles. Unused methods should be marked as deprecated.
@@ -39,52 +39,52 @@ public interface ActiveMQAMQPProtocolMessageBundle {
 
    ActiveMQAMQPProtocolMessageBundle BUNDLE = Messages.getBundle(ActiveMQAMQPProtocolMessageBundle.class);
 
-   @Message(id = 219000, value = "target address not set")
+   @Message(id = 119000, value = "target address not set")
    ActiveMQAMQPInvalidFieldException targetAddressNotSet();
 
-   @Message(id = 219001, value = "error creating temporary queue, {0}", format = Message.Format.MESSAGE_FORMAT)
+   @Message(id = 119001, value = "error creating temporary queue, {0}", format = Message.Format.MESSAGE_FORMAT)
    ActiveMQAMQPInternalErrorException errorCreatingTemporaryQueue(String message);
 
-   @Message(id = 219002, value = "target address does not exist")
+   @Message(id = 119002, value = "target address does not exist")
    ActiveMQAMQPNotFoundException addressDoesntExist();
 
-   @Message(id = 219003, value = "error finding temporary queue, {0}", format = Message.Format.MESSAGE_FORMAT)
+   @Message(id = 119003, value = "error finding temporary queue, {0}", format = Message.Format.MESSAGE_FORMAT)
    ActiveMQAMQPNotFoundException errorFindingTemporaryQueue(String message);
 
-   @Message(id = 219005, value = "error creating consumer, {0}", format = Message.Format.MESSAGE_FORMAT)
+   @Message(id = 119005, value = "error creating consumer, {0}", format = Message.Format.MESSAGE_FORMAT)
    ActiveMQAMQPInternalErrorException errorCreatingConsumer(String message);
 
-   @Message(id = 219006, value = "error starting consumer, {0}", format = Message.Format.MESSAGE_FORMAT)
+   @Message(id = 119006, value = "error starting consumer, {0}", format = Message.Format.MESSAGE_FORMAT)
    ActiveMQAMQPIllegalStateException errorStartingConsumer(String message);
 
-   @Message(id = 219007, value = "error acknowledging message {0}, {1}", format = Message.Format.MESSAGE_FORMAT)
+   @Message(id = 119007, value = "error acknowledging message {0}, {1}", format = Message.Format.MESSAGE_FORMAT)
    ActiveMQAMQPIllegalStateException errorAcknowledgingMessage(String messageID, String message);
 
-   @Message(id = 219008, value = "error cancelling message {0}, {1}", format = Message.Format.MESSAGE_FORMAT)
+   @Message(id = 119008, value = "error cancelling message {0}, {1}", format = Message.Format.MESSAGE_FORMAT)
    ActiveMQAMQPIllegalStateException errorCancellingMessage(String messageID, String message);
 
-   @Message(id = 219010, value = "source address does not exist")
+   @Message(id = 119010, value = "source address does not exist")
    ActiveMQAMQPNotFoundException sourceAddressDoesntExist();
 
-   @Message(id = 219011, value = "source address not set")
+   @Message(id = 119011, value = "source address not set")
    ActiveMQAMQPInvalidFieldException sourceAddressNotSet();
 
-   @Message(id = 219012, value = "error rolling back coordinator: {0}", format = Message.Format.MESSAGE_FORMAT)
+   @Message(id = 119012, value = "error rolling back coordinator: {0}", format = Message.Format.MESSAGE_FORMAT)
    ActiveMQAMQPIllegalStateException errorRollingbackCoordinator(String message);
 
-   @Message(id = 219013, value = "error committing coordinator: {0}", format = Message.Format.MESSAGE_FORMAT)
+   @Message(id = 119013, value = "error committing coordinator: {0}", format = Message.Format.MESSAGE_FORMAT)
    ActiveMQAMQPIllegalStateException errorCommittingCoordinator(String message);
 
-   @Message(id = 219014, value = "Transaction not found: xid={0}", format = Message.Format.MESSAGE_FORMAT)
+   @Message(id = 119014, value = "Transaction not found: xid={0}", format = Message.Format.MESSAGE_FORMAT)
    ActiveMQAMQPIllegalStateException txNotFound(String xidToString);
 
-   @Message(id = 219015, value = "not authorized to create consumer, {0}", format = Message.Format.MESSAGE_FORMAT)
+   @Message(id = 119015, value = "not authorized to create consumer, {0}", format = Message.Format.MESSAGE_FORMAT)
    ActiveMQAMQPSecurityException securityErrorCreatingConsumer(String message);
 
-   @Message(id = 219016, value = "not authorized to create temporary destination, {0}", format = Message.Format.MESSAGE_FORMAT)
+   @Message(id = 119016, value = "not authorized to create temporary destination, {0}", format = Message.Format.MESSAGE_FORMAT)
    ActiveMQAMQPSecurityException securityErrorCreatingTempDestination(String message);
 
-   @Message(id = 219017, value = "not authorized to create producer, {0}", format = Message.Format.MESSAGE_FORMAT)
+   @Message(id = 119017, value = "not authorized to create producer, {0}", format = Message.Format.MESSAGE_FORMAT)
    ActiveMQAMQPSecurityException securityErrorCreatingProducer(String message);
 
 }

http://git-wip-us.apache.org/repos/asf/activemq-artemis/blob/b3529dce/artemis-protocols/artemis-mqtt-protocol/src/main/java/org/apache/activemq/artemis/core/protocol/mqtt/MQTTLogger.java
----------------------------------------------------------------------
@@ -28,8 +28,8 @@ import org.jboss.logging.annotations.MessageBundle;
  * Logger Code 11
  * <p>
- * Each message id must be 6 digits long starting with 10, the 3rd digit should be 9. So the range
- * is from 219000 to 119999.
+ * Each message id must be 6 digits long starting with 11, the 3rd digit should be 9. So the range
+ * is from 119000 to 119999.
  * <p>
  * Once released, methods should not be deleted as they may be referenced by knowledge base